@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "hindent" "6.2.1"
+(define-package "hindent" "6.3.0"
   "Indent haskell code using the \"hindent\" program."
-  '((cl-lib "0.5"))
-  :url "https://github.com/chrisdone/hindent"
-  :commit "beafb2610fb9a724bdd78339375e6673d46c23fe"
-  :revdesc "beafb2610fb9"
+  '((emacs "27.1"))
+  :url "https://github.com/mihaimaruseac/hindent"
+  :commit "57e769d48447c77da5a21d1923ba3634e3a605fe"
+  :revdesc "57e769d48447"
   :authors '(("Chris Done" . "chrisdone@gmail.com"))
   :maintainers '(("Chris Done" . "chrisdone@gmail.com")))
